@@ -361,3 +361,20 @@ def camel_to_snake(camel_str: str) -> str:
     """Converts camelCase to snake_case."""
     snake_str = re.sub(r'(?<!^)(?=[A-Z])', '_', camel_str).lower()
     return snake_str
+
+
+def strtobool(val):
+    """Convert a string representation of truth to true (1) or false (0).
+    True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
+    are 'n', 'no', 'f', 'false', 'off', and '0'.  Raises ValueError if
+    'val' is anything else.
+    """
+    if val is None:
+        return 0
+    val = val.lower()
+    if val in ('y', 'yes', 't', 'true', 'on', '1'):
+        return 1
+    elif val in ('n', 'no', 'f', 'false', 'off', '0'):
+        return 0
+    else:
+        raise ValueError("invalid truth value %r" % (val,))
